; bedleveling.g
; wird von bed.g aufgerufen, wenn der User den entsprechenden Menüpunkt wählt
; für manuelle Bettkompensation via G32
; Funktion: Hotend 1 fährt die drei Schraubenpunkte an und fordert zum Korrigieren der beiden vorderen Punkte auf
; Die Druckplattendicke ist bereits in der Auslösehöhe der Sensoren in der config.g berücksichtigt und sollte hier daher nicht mehr notwendig sein
; Achtung: Axes are mapped in the order XYZUVWABC, where X=0, Y=1, Z=2, U=3 etc, not by driver number
; Achtung: bei Verwendung von globalen Variablen im Makro kann der Befehl, der die globale Variable nutzt, außerhalb der Reihe ablaufen. 
;          Mindestens M400 davorsetzen, besser die globale Variable in eine lokale überführen!

; TODO: Snapmaker ändert die Stallguard-Einstellungen beim Kalibrieren. Erst Stallguard 27, dann 42 (muß auf den anderen Stepper erst umgerechnet werden!)

; Variablen
var Startmesshoehe = 1              ; Meßhöhe über der UNTERkante der Druckplatte, wie in der config.g definiert
var Zmax_neu = 0
var delta_z = 0
var Referenzwert = vector(7,null)   ; die Arraygröße legt die Anzahl der Referenzmessungen nach den ersten drei Antastungen fest 
var Referenzmittelwert = 0.0
var Referenzstandardabw = 0.0
var ReferenzZScore = vector(#var.Referenzwert,null)
var ZScoregrenze = 0.5              ; Referenzmeßwerte mit einem größeren Z-Score werden ignoriert
var Anzahlgueltig = 0
var Messwert = 0
var Messung1 = false
var Messung2 = false
var loopcount = 0
; Meßzeiten. Zum Vergleich: bei der Routine von Snapmaker dauert ein Meßzyḱlus ca. 1,4s. Viel schneller as 2s scheint die PanelDue nicht zu schaffen.
var Wartezeit = 500                 ; Millisekunden zusätzlich zur Dauer der Messung
var Nachrichtenanzeige = 1.4        ; Sekunden. So anpassen, daß die PanelDue keinen Schluckauf kriegt...

; Homing auf jeden Fall durchführen, um die Achsen aus dem Weg zu haben!
; Macht eh Sinn, damit die Referenzpunkte frisch sind.
G28                                 ; Homing durchführen

; Plattform auf 120mm fahren, dann Glasplatte entfernen
G1 H2 Z180 F6000                    ; Bett ca. 30mm hochfahren
M400                                ; warten, bis die Bewegung abgeschlossen ist
M291 S4 K{"Weiter","Abbruch"} T1 P"Bitte die Glasplatte vom Druckbett entfernen! Dann mit ''Weiter'' den Kalibriervorgang fortsetzen." R"Bettleveling"
if input = 1
    abort

; Druckköpfe und Bett aufheizen
M140 S60                            ; Bett auf 60°C aufheizen
M568 P0 S220                        ; Hotend 1 auf 220°C aufheizen
M116                                ; warten, bis die Temperaturen von Druckkopf und Bett erreicht sind


; Druckköpfe in Putzposition bewegen
G1 H2 X{move.axes[0].min+50} F3000  ; Hotend 1 50mm von der Parkposition wegbewegen, um die Düse abwischen zu können
M400                                ; warten, bis die Bewegung abgeschlossen ist


; Nachricht
M291 S2 P"Bettleveling ist nur mit sauberer Druckdüse möglich. Bitte Materialreste von Druckbett und Hotend entfernen! Dann mit ''OK'' fortsetzen." R"Hinweis"


; Druckköpfe zurückbewegen
G1 H2 X{move.axes[0].min} F3000     ; Hotend 1 zurück auf Endposition



; Bett hochbewegen
G1 H2 Z2 F6000                      ; Bett auf Z=2 fahren
; !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
; ACHTUNG: Bett immer erst dann ins negative fahren, wenn das Hotend an seinem Platz steht, sonst kann es sich an den Druckplattenhaltern verhaken!
; !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

; Motorströme zur Sicherheit reduzieren
M913 Z50                            ; Motorstrom auf 70% reduzieren

; Meßpunkt hinten anfahren
G1 H2 X0 Y86 F4500                  ; zu Einstellschraube 1 (hinten Mitte) fahren
M400                                ; warten, bis die Bewegung abgeschlossen ist
G1 H2 Z{-global.Druckplattendicke + var.Startmesshoehe} F6000                        ; Bett wieder ganz hoch fahren
M400                                ; warten, bis die Bewegung abgeschlossen ist

; 1. Messung = Referenzmessung durchführen
M558 P8 C"^!io7.in" H5 F50 R0.2 T720 K0 B0          ; Meßgeschwindigkeit heruntersetzen
G31 K0 P500 X0 Y0 Z{-global.Druckplattendicke-2}    ; Z-Sensor Hotend 1: Triggerwert, Offset und Auslösehöhe

while iterations <3                ; 3x messen ohne den Wert zu speichern, damit sich das Hotend setzt
    G4 P{var.Wartezeit}            ; warten
    G30 S-1 K0
    G1 H2 Z{sensors.probes[0].lastStopHeight + var.Startmesshoehe} F3000                ; wieder anheben
    if sensors.probes[0].lastStopHeight = 0
        M291 S2 K{"Abbruch",} T1 P"Meßpunkt konnte nicht ermittelt werden. Bitte die Grenze der Z-Achse in z_max.g bzw. die Betthposition manuell grob korrigieren" R"Fehler"
        if input = 0
            abort

; Referenzwertarray füllen
while iterations < #var.Referenzwert    ; so oft wie von der Arraygröße vorgegeben messen
    G4 P{var.Wartezeit}                 ; warten
    G30 S-1 K0                          ; Z mit dem linken Hotend messen
    set var.Referenzwert[iterations] = sensors.probes[0].lastStopHeight
    G1 H2 Z{sensors.probes[0].lastStopHeight + var.Startmesshoehe} F3000                ; wieder anheben

; Mittelwert errechnen
while iterations < #var.Referenzwert
    set var.Referenzmittelwert = var.Referenzmittelwert + var.Referenzwert[iterations]
set var.Referenzmittelwert = var.Referenzmittelwert / #var.Referenzwert

; Standardabweichung errechnen
while iterations < #var.Referenzwert
    set var.Referenzstandardabw = var.Referenzstandardabw + (var.Referenzwert[iterations] - var.Referenzmittelwert) * (var.Referenzwert[iterations] - var.Referenzmittelwert)
set var.Referenzstandardabw = sqrt(var.Referenzstandardabw / (#var.Referenzwert - 1))

; Z-Score für jeden Meßwert errechnen
while iterations < #var.Referenzwert
    set var.ReferenzZScore[iterations] = (var.Referenzwert[iterations] - var.Referenzmittelwert) / var.Referenzstandardabw

; für falsch befundene Werte rauswerfen und richtigen Mittelwert für weitere Verwendung errechnen
set var.Referenzmittelwert = 0
while iterations < #var.Referenzwert
    if var.ReferenzZScore[iterations] < var.ZScoregrenze            ; nur Werte nehmen, die keine Ausreißer sind 
        set var.Referenzmittelwert = var.Referenzmittelwert + var.Referenzwert[iterations]
        set var.Anzahlgueltig = var.Anzahlgueltig + 1
set var.Referenzmittelwert = var.Referenzmittelwert / var.Anzahlgueltig

M558 P8 C"^!io7.in" H5 F150 R0.2 T720 K0 B0         ; Meßgeschwindigkeit normal
G31 K0 P500 X0 Y0 Z{-global.Druckplattendicke-2}    ; Z-Sensor Hotend 1: Triggerwert, Offset und Auslösehöhe


; 2. Messung durchführen und den Benutzer korrigieren lassen

; Bett wieder aus dem Weg bewegen
G1 H2 Z2 F6000                                                ;  Bett wieder auf Z=2 bewegen

; Meßpunkt vorn links anfahren
G1 H2 X-114.5 Y-93 F4500                                      ; zu Einstellschraube 2 (vo.li) fahren
M400                                                          ; warten, bis die Bewegung abgeschlossen ist
G1 H2 Z{-global.Druckplattendicke + var.Startmesshoehe} F6000 ; Bett wieder ganz hoch fahren
M400                                                          ; warten, bis die Bewegung abgeschlossen ist

; Loop starten
while var.Messung1 = false
    set var.loopcount = 0          ; falls aus der inneren Schleife rausgehüpft wird, Loopcounter resetten
    G4 P{var.Wartezeit}            ; warten
    G30 S-1 K0                     ; Z mit dem linken Hotend messen
    set var.Messwert = sensors.probes[0].lastStopHeight - var.Referenzmittelwert
    G1 H2 Z{move.axes[2].machinePosition + var.Startmesshoehe} F3000                ; wieder anheben
    if var.Messwert > 0.5
        M291 S1 T{var.Nachrichtenanzeige} P">|<==========-__-==========" R"Linke Betteinstellschraube drehen"
    elif var.Messwert <= 0.5 && var.Messwert > 0.45
        M291 S1 T{var.Nachrichtenanzeige} P"=>|<=========-__-==========" R"Linke Betteinstellschraube drehen"
    elif var.Messwert <= 0.45 && var.Messwert > 0.4
        M291 S1 T{var.Nachrichtenanzeige} P"==>|<========-__-==========" R"Linke Betteinstellschraube drehen"
    elif var.Messwert <= 0.4 && var.Messwert > 0.35
        M291 S1 T{var.Nachrichtenanzeige} P"===>|<=======-__-==========" R"Linke Betteinstellschraube drehen"
    elif var.Messwert <= 0.35 && var.Messwert > 0.3
        M291 S1 T{var.Nachrichtenanzeige} P"====>|<======-__-==========" R"Linke Betteinstellschraube drehen"
    elif var.Messwert <= 0.3 && var.Messwert > 0.25
        M291 S1 T{var.Nachrichtenanzeige} P"=====>|<=====-__-==========" R"Linke Betteinstellschraube drehen"
    elif var.Messwert <= 0.25 && var.Messwert > 0.2
        M291 S1 T{var.Nachrichtenanzeige} P"======>|<====-__-==========" R"Linke Betteinstellschraube drehen"
    elif var.Messwert <= 0.2 && var.Messwert > 0.15
        M291 S1 T{var.Nachrichtenanzeige} P"=======>|<===-__-==========" R"Linke Betteinstellschraube drehen"
    elif var.Messwert <= 0.15 && var.Messwert > 0.1
        M291 S1 T{var.Nachrichtenanzeige} P"========>|<==-__-==========" R"Linke Betteinstellschraube drehen"
    elif var.Messwert <= 0.1 && var.Messwert > 0.05
        M291 S1 T{var.Nachrichtenanzeige} P"=========>|<=-__-==========" R"Linke Betteinstellschraube drehen"
    elif var.Messwert <= 0.05 && var.Messwert > 0.03
        M291 S1 T{var.Nachrichtenanzeige} P"==========>|<-__-==========" R"Linke Betteinstellschraube drehen"
            ; There is no non-blocking and time-out-able message the user can acknowledge
            ; Workaround: verify measurement several times, then display a blocking message
    elif var.Messwert <= 0.03 && var.Messwert >= -0.03
        while var.Messwert <= 0.03 && var.Messwert >= -0.03 && var.loopcount <= 6    ; okay, but verify some times...
            if iterations > 0                  ; nicht für die erste Runde, da wurde ja oben schon gemessen
                G4 P{var.Wartezeit}            ; warten
                G30 S-1 K0                     ; Z mit dem linken Hotend messen
                set var.Messwert = sensors.probes[0].lastStopHeight - var.Referenzmittelwert
                G1 H2 Z{move.axes[2].machinePosition + var.Startmesshoehe} F3000                ; wieder anheben
            if var.Messwert <= 0.03 && var.Messwert > 0.01      ; just okay
                M291 S1 T{var.Nachrichtenanzeige} P"==========->|<__-==========" R"Linke Betteinstellschraube drehen"
                set var.loopcount = var.loopcount + 1
            elif var.Messwert <= 0.01 && var.Messwert >= -0.01     ; perfect
                M291 S1 T{var.Nachrichtenanzeige} P"==========-_>|<_-==========" R"Linke Betteinstellschraube drehen"
                set var.loopcount = var.loopcount + 1
            elif var.Messwert < -0.01 && var.Messwert >= -0.03     ; just okay
                M291 S1 T{var.Nachrichtenanzeige} P"==========-__>|<-==========" R"Linke Betteinstellschraube drehen"
                set var.loopcount = var.loopcount + 1
            if var.loopcount = 6 && var.Messwert <= 0.03 && var.Messwert >= -0.03
                M300 S2000 P200                ; B
                G4 P200                        ; e
                M300 S2500 P300                ; e
                G4 P300                        ; p
                M291 S4 K{"Weiter","Zurück"} T1 P"Betteinstellschraube justiert! Weiter zum nächsten Meßpunkt?" R"Linke Betteinstellschraube justiert"
                if input = 0
                    set var.Messung1 = true
                    set var.loopcount = 99                    ; raus aus dem ganzen While-Gedöns
                if input = 1
                    set var.loopcount = 0
    elif var.Messwert < -0.03 && var.Messwert >= -0.05
        M291 S1 T{var.Nachrichtenanzeige} P"==========-__->|<==========" R"Linke Betteinstellschraube drehen"
    elif var.Messwert < -0.05 && var.Messwert >= -0.1
        M291 S1 T{var.Nachrichtenanzeige} P"==========-__-=>|<=========" R"Linke Betteinstellschraube drehen"
    elif var.Messwert < -0.1 && var.Messwert >= -0.15
        M291 S1 T{var.Nachrichtenanzeige} P"==========-__-==>|<========" R"Linke Betteinstellschraube drehen"
    elif var.Messwert < -0.15 && var.Messwert >= -0.2
        M291 S1 T{var.Nachrichtenanzeige} P"==========-__-===>|<=======" R"Linke Betteinstellschraube drehen"
    elif var.Messwert < -0.2 && var.Messwert >= -0.25
        M291 S1 T{var.Nachrichtenanzeige} P"==========-__-====>|<======" R"Linke Betteinstellschraube drehen"
    elif var.Messwert < -0.25 && var.Messwert >= -0.3
        M291 S1 T{var.Nachrichtenanzeige} P"==========-__-=====>|<=====" R"Linke Betteinstellschraube drehen"
    elif var.Messwert < -0.3 && var.Messwert >= -0.35
        M291 S1 T{var.Nachrichtenanzeige} P"==========-__-======>|<====" R"Linke Betteinstellschraube drehen"
    elif var.Messwert < -0.35 && var.Messwert >= -0.4
        M291 S1 T{var.Nachrichtenanzeige} P"==========-__-=======>|<===" R"Linke Betteinstellschraube drehen"
    elif var.Messwert < -0.4 && var.Messwert >= -0.45
        M291 S1 T{var.Nachrichtenanzeige} P"==========-__-========>|<==" R"Linke Betteinstellschraube drehen"
    elif var.Messwert < -0.45 && var.Messwert >= -0.5
        M291 S1 T{var.Nachrichtenanzeige} P"==========-__-=========>|<=" R"Linke Betteinstellschraube drehen"
    elif var.Messwert < -0.5 
        M291 S1 T{var.Nachrichtenanzeige} P"==========-__-==========>|<" R"Linke Betteinstellschraube drehen"


; 3. Messung durchführen und den Benutzer korrigieren lassen

; Bett wieder aufwärts bewegen
G1 H2 Z2 F6000                                                ;  Bett wieder auf Z=2 bewegen

; Meßpunkt vorn rechts anfahren
G1 H2 X114.5 Y-93 F4500                                       ; zu Einstellschraube 3 (vo.re) fahren
M400                                                          ; warten, bis die Bewegung abgeschlossen ist
G1 H2 Z{-global.Druckplattendicke + var.Startmesshoehe} F6000 ; Bett wieder ganz hoch fahren
M400                                                          ; warten, bis die Bewegung abgeschlossen ist


; Loop starten
while var.Messung2 = false
    set var.loopcount = 0                                                              ; falls aus der inneren Schleife rausgehüpft wird, Loopcounter resetten
    G4 P{var.Wartezeit}                                                                ; 0,2s warten
    G30 S-1 K0                                                                         ; Z mit dem linken Hotend messen
    set var.Messwert = sensors.probes[0].lastStopHeight - var.Referenzmittelwert
    G1 H2 Z{move.axes[2].machinePosition + var.Startmesshoehe} F3000                   ; wieder anheben
    if var.Messwert > 0.5
        M291 S1 T{var.Nachrichtenanzeige} P">|<==========-__-==========" R"Rechte Betteinstellschraube drehen"
    elif var.Messwert <= 0.5 && var.Messwert > 0.45
        M291 S1 T{var.Nachrichtenanzeige} P"=>|<=========-__-==========" R"Rechte Betteinstellschraube drehen"
    elif var.Messwert <= 0.45 && var.Messwert > 0.4
        M291 S1 T{var.Nachrichtenanzeige} P"==>|<========-__-==========" R"Rechte Betteinstellschraube drehen"
    elif var.Messwert <= 0.4 && var.Messwert > 0.35
        M291 S1 T{var.Nachrichtenanzeige} P"===>|<=======-__-==========" R"Rechte Betteinstellschraube drehen"
    elif var.Messwert <= 0.35 && var.Messwert > 0.3
        M291 S1 T{var.Nachrichtenanzeige} P"====>|<======-__-==========" R"Rechte Betteinstellschraube drehen"
    elif var.Messwert <= 0.3 && var.Messwert > 0.25
        M291 S1 T{var.Nachrichtenanzeige} P"=====>|<=====-__-==========" R"Rechte Betteinstellschraube drehen"
    elif var.Messwert <= 0.25 && var.Messwert > 0.2
        M291 S1 T{var.Nachrichtenanzeige} P"======>|<====-__-==========" R"Rechte Betteinstellschraube drehen"
    elif var.Messwert <= 0.2 && var.Messwert > 0.15
        M291 S1 T{var.Nachrichtenanzeige} P"=======>|<===-__-==========" R"Rechte Betteinstellschraube drehen"
    elif var.Messwert <= 0.15 && var.Messwert > 0.1
        M291 S1 T{var.Nachrichtenanzeige} P"========>|<==-__-==========" R"Rechte Betteinstellschraube drehen"
    elif var.Messwert <= 0.1 && var.Messwert > 0.05
        M291 S1 T{var.Nachrichtenanzeige} P"=========>|<=-__-==========" R"Rechte Betteinstellschraube drehen"
    elif var.Messwert <= 0.05 && var.Messwert > 0.03
        M291 S1 T{var.Nachrichtenanzeige} P"==========>|<-__-==========" R"Rechte Betteinstellschraube drehen"
            ; Es gibt keine nicht-blockierende Nachricht mit Timeout und Benutzerinteraktion
            ; Workaround: mehrfach verifizieren, dann pausieren und Nachricht anzeigen 
    elif var.Messwert <= 0.03 && var.Messwert >= -0.03
        while var.Messwert <= 0.03 && var.Messwert >= -0.03 && var.loopcount <= 6       ; okay, verifizeren...
            if iterations > 0                                                           ; nicht für die erste Runde, da wurde ja oben schon gemessen
                G4 P{var.Wartezeit}                                                     ; 0,2s warten
                G30 S-1 K0                                                              ; Z mit dem linken Hotend messen
                set var.Messwert = sensors.probes[0].lastStopHeight - var.Referenzmittelwert
                G1 H2 Z{move.axes[2].machinePosition + var.Startmesshoehe} F3000        ; wieder anheben
            if var.Messwert <= 0.03 && var.Messwert > 0.01                              ; noch okay
                M291 S1 T{var.Nachrichtenanzeige} P"==========->|<__-==========" R"Rechte Betteinstellschraube drehen"
                set var.loopcount = var.loopcount + 1
            elif var.Messwert <= 0.01 && var.Messwert >= -0.01                          ; perfekt
                M291 S1 T{var.Nachrichtenanzeige} P"==========-_>|<_-==========" R"Rechte Betteinstellschraube drehen"
                set var.loopcount = var.loopcount + 1
            elif var.Messwert < -0.01 && var.Messwert >= -0.03                          ; noch okay
                M291 S1 T{var.Nachrichtenanzeige} P"==========-__>|<-==========" R"Rechte Betteinstellschraube drehen"
                set var.loopcount = var.loopcount + 1
            if var.loopcount = 6 && var.Messwert <= 0.03 && var.Messwert >= -0.03
                M300 S2000 P200                                                         ; B
                G4 P200                                                                 ; e
                M300 S2500 P300                                                         ; e
                G4 P300                                                                 ; p
                M291 S4 K{"Fertig","Zurück"} T1 P"Betteinstellschraube justiert! Messung beenden?" R"Rechte Betteinstellschraube justiert"
                if input = 0
                    set var.Messung2 = true
                    set var.loopcount = 99                                              ; raus aus dem ganzen While-Gedöns
                if input = 1
                    set var.loopcount = 0
    elif var.Messwert < -0.03 && var.Messwert >= -0.05
        M291 S1 T{var.Nachrichtenanzeige} P"==========-__->|<==========" R"Rechte Betteinstellschraube drehen"
    elif var.Messwert < -0.05 && var.Messwert >= -0.1
        M291 S1 T{var.Nachrichtenanzeige} P"==========-__-=>|<=========" R"Rechte Betteinstellschraube drehen"
    elif var.Messwert < -0.1 && var.Messwert >= -0.15
        M291 S1 T{var.Nachrichtenanzeige} P"==========-__-==>|<========" R"Rechte Betteinstellschraube drehen"
    elif var.Messwert < -0.15 && var.Messwert >= -0.2
        M291 S1 T{var.Nachrichtenanzeige} P"==========-__-===>|<=======" R"Rechte Betteinstellschraube drehen"
    elif var.Messwert < -0.2 && var.Messwert >= -0.25
        M291 S1 T{var.Nachrichtenanzeige} P"==========-__-====>|<======" R"Rechte Betteinstellschraube drehen"
    elif var.Messwert < -0.25 && var.Messwert >= -0.3
        M291 S1 T{var.Nachrichtenanzeige} P"==========-__-=====>|<=====" R"Rechte Betteinstellschraube drehen"
    elif var.Messwert < -0.3 && var.Messwert >= -0.35
        M291 S1 T{var.Nachrichtenanzeige} P"==========-__-======>|<====" R"Rechte Betteinstellschraube drehen"
    elif var.Messwert < -0.35 && var.Messwert >= -0.4
        M291 S1 T{var.Nachrichtenanzeige} P"==========-__-=======>|<===" R"Rechte Betteinstellschraube drehen"
    elif var.Messwert < -0.4 && var.Messwert >= -0.45
        M291 S1 T{var.Nachrichtenanzeige} P"==========-__-========>|<==" R"Rechte Betteinstellschraube drehen"
    elif var.Messwert < -0.45 && var.Messwert >= -0.5
        M291 S1 T{var.Nachrichtenanzeige} P"==========-__-=========>|<=" R"Rechte Betteinstellschraube drehen"
    elif var.Messwert < -0.5 
        M291 S1 T{var.Nachrichtenanzeige} P"==========-__-==========>|<" R"Rechte Betteinstellschraube drehen"


; Z-Wert und Z-Achsenlimit korrigieren
; z.B.         209          -   -3,98          -     5   = 207,98
set var.Zmax_neu = move.axes[2].max - var.Referenzmittelwert - global.Druckplattendicke   ; neues Zmax errechnen
set var.delta_z = move.axes[2].max - var.Zmax_neu                                   ; eigentlich nicht nötig, aber für leichteres Nachvollziehen...
if var.Zmax_neu < global.Z_Limit_max && var.Zmax_neu > global.Z_Limit_min           ; falls der ermittelte Wert innerhalb der Grenzwerte aus der config.pro ist
    M208 Z{var.Zmax_neu} S0                                                         ; Z-Achsenlimit korrigieren
    echo >"Korrekturwert_z_max.g" "M208 Z"^{var.Zmax_neu}^" S0"                     ; Z-Max-Wert für den nächsten Boot speichern
else
    M291 S2 P{"Die ermittelte Korrektur der Z-Achse ist "^var.delta_z^". Dies überschreitet das mechanische Limit der Z-Achse. Werte werden nicht gespeichert, bitte erneut messen!"}  R"Abbruch"

G1 H2 Z5 F6000                                          ; Bett wieder auf Z=5 bewegen
M913 Z100                                               ; Motorstrom wieder auf Nennwert
G1 H2 X{move.axes[0].min} Y{move.axes[1].min} F4500     ; Druckkopf wieder zurückfahren
G1 Z120 F6000                                           ; Z wieder auf 120mm
G28 Z                                                   ; Z homen, um die 
M568 P0 S0                                              ; Hotend 1 aus
M140 S0                                                 ; Bett aus
M291 S2 P"Z-Leveling des Druckbetts abgeschlossen! Bitte Druckplatte wieder auflegen!"



