; tool1_xy_offset.g
; wird von bed.g aufgerufen, wenn der User den entsprechenden Menüpunkt wählt
; XY-Kalibrierung Hotend 2 rechts (T1) an Hotend 1 links (T0)
;
; Funktion: Hotend 1 ermittelt den Mittelpunkt des Lochs in der Mitte. Hotend 2 tut dasselbe, au den Ergebnissen wird dann der Offset von Hotend 2 berechnet.
; Achtung: Axes are mapped in the order XYZUVWABC, where X=0, Y=1, Z=2, U=3 etc, not by driver number
; Achtung: bei Verwendung von globalen Variablen im Makro kann der Befehl, der die globale Variable nutzt, außerhalb der Reihe ablaufen. 
;          Mindestens M400 davorsetzen, besser die globale Variable in eine lokale überführen!

; TODO: Snapmaker ändert die Stallguard-Einstellungen beim Kalibrieren - erst 27, dann 42. Muß auf den anderen Stepper der Duet umgerechnet werden!

; Die XY-Korrektur muß dann folgendes machen:
; Druckkopf 1 als Referenz nutzen, damit auf 0,0 fahren, absenken und die exakte Lage der Mitte der Öffnung in X und in Y ermitteln:
;       Mitte x = X-Koordinate Anschlag rechts - X-Koordinate Anschlag links
;       Mitte y = Y-Koordinate Anschlag hinten - Y-Koordinate Anschlag vorn
; Hotend 1 fährt in Parkposition
; dann Öffnung mit Druckkopf 2 anfahren und Offset in X und Y berechnen
;       Mitte2 x = X-Koordinate Anschlag rechts - X-Koordinate Anschlag links
;       Mitte2 y = Y-Koordinate Anschlag hinten - Y-Koordinate Anschlag vorn
;       Offset x = Mitte2 x - Mitte x
;       Offset y = Mitte2 y - Mitte y
; Hotend 2 fährt in Parkposition
; Korrekturkoordinaten für Hotend 2 werden berechnet und als Offset für Hotend 2 gespeichert

; Filterung von Ausreißern ist hier erfahrungsgemäß nicht nötig, solange der Benutzer die Düsen anständig geputzt hat
 
; Variablen
var Eintauchtiefe = 1           ; Eintauchtiefe ohne Druckplattendicke
var Referenzwert_X = 0
var Referenzwert_Y = 0
var Hotend2_X = 0
var Hotend2_Y = 0
var Messung1 = false
var loopcount = 0

; Homing auf jeden Fall durchführen, um die Achsen aus dem Weg zu haben!
; Macht eh Sinn, damit die Referenzpunkte frisch sind.
G28                             ; Homing durchführen

; Plattform auf 120mm fahren, dann Glasplatte entfernen
G1 H2 Z180 F6000                ; Bett ca. 30mm hochfahren
M400                            ; warten, bis die Bewegung abgeschlossen ist
M291 S4 K{"Weiter","Abbruch"} T1 P"Bitte die Glasplatte vom Druckbett entfernen! Dann mit ''Weiter'' den Kalibriervorgang fortsetzen." R"Z-Korrektur Hotend 2"
if input = 1
    abort

; Druckköpfe und Bett aufheizen
M140 S60                        ; Bett auf 60°C aufheizen
T0 P0
M568 P0 S220 R220               ; Hotend 1 auf 220°C aufheizen, auch im Standby
T1 P0
M568 P1 S220 R220               ; Hotend 2 auf 220°C aufheizen, auch im Standby
T-1 P0
M116                            ; warten, bis die Temperaturen von Druckkopf und Bett erreicht sind
; M291 P"Hotends und Druckbett sind aufgeheizt. Zum Kalibrieren OK drücken." R"Bettleveling" S3 <-- nutzlose Nachricht, weg damit


; Druckköpfe in Putzposition bewegen
G1 H2 X{move.axes[0].min+50} F3000  ; Hotend 1 50mm von der Parkposition wegbewegen, um die Düse abwischen zu können
G1 H2 U{move.axes[3].max-50} F3000  ; Hotend 2 50mm von der Parkposition wegbewegen, um die Düse abwischen zu können
M400                                ; warten, bis die Bewegung abgeschlossen ist

; Nachricht
; M291 P"XY-Ausgleich der Hotends ist nur mit sauberen Druckdüsen möglich. Bitte Materialreste von Druckbett und Hotends entfernen" R"Hinweis" S3
M291 P"Der Kalibriervorgang benötigt saubere Druckdüsen. Bitte warten, bis die Hotends nicht mehr nachtropfen, dann die Düsen gründlich abwischen!" R"Hinweis" S3

; Druckköpfe zurückbewegen
G1 H2 X{move.axes[0].min} F3000     ; Hotend 1 zurück auf Parkposition
G1 H2 U{move.axes[3].max} F3000     ; Hotend 2 zurück auf Parkposition


; Bett hochbewegen
G1 H2 Z5 F6000                      ; Bett wieder fast ganz hoch fahren

; Motorströme zur Sicherheit reduzieren
; M913 X70 Y70 U70                  ; Motorstrom auf 70% reduzieren - TODO vernünftigen Minimalwert festlegen!

; Meßöffnung mit Hotend 1 anfahren
G1 H2 X0 Y0 F6000                   ; Hotend 1 zu Meßöffnung fahren
M400                                ; warten, bis die Bewegung abgeschlossen ist
G1 H2 Z{-global.Druckplattendicke - var.Eintauchtiefe} F3000 ; eintauchen

; 1. Messung = Referenzmessung durchführen

T0 P0                               ; linkes Hotend = Tool 0 ohne Wechselmakroausführung aktivieren
while iterations < 8                ; 8x messen und Ergebnis auswerten
    M675 X R1 P0 F100               ; in X messen
    M400
    set var.Referenzwert_X = var.Referenzwert_X + move.axes[0].machinePosition   ; Position in Variabler speichern
set var.Referenzwert_X = var.Referenzwert_X / 8 
    
while iterations < 8                ; 8x messen und Ergebnis auswerten    
    M675 Y R1 P0 F100               ; in Y messen
    M400
    set var.Referenzwert_Y = var.Referenzwert_Y + move.axes[1].machinePosition   ; Position in Variabler speichern
set var.Referenzwert_Y = var.Referenzwert_Y / 8

; Hotend 1 zurückfahren
G1 H2 Z2 F6000                      ; Bett absenken
M400
G1 H2 X{move.axes[0].min} F6000     ; Hotend 1 zurückfahren

; alten Offset von Hotend 2 löschen:
G10 P1 U0 Y0

; Meßöffnung mit Hotend 2 anfahren
G1 H2 U0 Y0 F6000                   ; Hotend 2 zu Meßöffnung fahren
M400                                ; warten, bis die Bewegung abgeschlossen ist
G1 H2 Z{-global.Druckplattendicke - var.Eintauchtiefe} F3000 ; eintauchen


; 2. Messung mit Hotend 2 durchführen
T1 P0                               ; rechtes Hotend = Tool 1 ohne Wechselmakroausführung aktivieren

while iterations < 8                ; 8x messen und Ergebnis auswerten
    M675 U R1 P1 F100               ; in U messen
    M400
    set var.Hotend2_X = var.Hotend2_X + move.axes[3].machinePosition   ; Position in Variabler speichern
set var.Hotend2_X = var.Hotend2_X / 8

while iterations < 8                ; 8x messen und Ergebnis auswerten
    M675 Y R1 P1 F100               ; in Y messen
    M400
    set var.Hotend2_Y = var.Hotend2_Y + move.axes[1].machinePosition   ; Position in Variabler speichern
set var.Hotend2_Y = var.Hotend2_Y / 8

; Offset von Tool 1 neu festlegen:
; Tool-Offsets werden vom Druckwert abgezogen!
; Beispiel - rechter Kopf 1mm zu weit rechts, linker Kopf paßt perfekt: G10 U{0 - 1} = G10 U1 - wird aufaddiert --> rechter Druckkopf druckt auf -1mm, wenn im Code 0mm steht     
G10 P1 U{var.Referenzwert_X - var.Hotend2_X} Y{var.Referenzwert_Y - var.Hotend2_Y}
echo >"Korrekturwert_xy_offset_tool1.g" "G10 P1 U"^{var.Referenzwert_X - var.Hotend2_X}^" Y"^{var.Referenzwert_Y - var.Hotend2_Y}^""    ; Z-Max-Wert für den nächsten Boot speichern

T0 P0                               ; Tool 1 wieder aktivieren - TODO: vorher speichern, welches Tool aktiv war und passende wieder aktivieren!

G1 H2 Z5 F6000                      ; Bett wieder auf Z=5 bewegen
; M913 X100 Y100 U100               ; Motorstrom wieder auf Nennwert
G1 H2 U{move.axes[3].max} Y{move.axes[1].min} F3000     ; Hotend 2 wieder zurückfahren
G1 Z120 F6000                       ; Z wieder auf 120mm
M568 P0 S0 R0                       ; Hotend 1 aus
M568 P1 S0 R0                       ; Hotend 2 aus
M140 S0                             ; Bett aus
M291 S2 P"XY-Offset des rechten Hotends ermittelt und gespeichert! Bitte Druckplatte wieder auflegen!"

M913 X100 Y100 U100                 ; Motorstrom wieder auf Nennwert
