; tool1_z_offset.g
; wird von bed.g aufgerufen, wenn der User den entsprechenden Menüpunkt wählt
; Z-Offset-Anpassung Hotend 2 rechts (T1) an Hotend 1 links (T0)
;
; Funktion: Hotend 1 fährt den Schraubenpunkt vorn rechts an. Hotend 2 fährt dann den gleichen Punkt an und fordert zum Kalibrieren auf.
; Die Druckplattendicke ist bereits in der Auslösehöhe der Sensoren in der config.g berücksichtigt und sollte hier daher nicht mehr notwendig sein
; Achtung: Axes are mapped in the order XYZUVWABC, where X=0, Y=1, Z=2, U=3 etc, not by driver number
; Achtung: bei Verwendung von globalen Variablen im Makro kann der Befehl, der die globale Variable nutzt, außerhalb der Reihe ablaufen. 
;          Mindestens M400 davorsetzen, besser die globale Variable in eine lokale überführen!

; TODO: Snapmaker ändert die Stallguard-Einstellungen beim Kalibrieren - erst 27, dann 42. Muß auf den anderen Stepper der Duet umgerechnet werden!

; Variablen
var Startmesshoehe = 1          ; Meßhöhe über der UNTERkante der Druckplatte, wie in der config.g definiert
var Referenzwert = vector(7,null)
var Referenzmittelwert = 0.0
var Referenzstandardabw = 0.0
var ReferenzZScore = vector(#var.Referenzwert,null)
var ZScoregrenze = 0.5
var Anzahlgueltig = 0
var Wert_Hotend2 = 0.0
var Messung1 = false
var loopcount = 0
; Meßzeiten. Zum Vergleich: bei der Routine von Snapmaker dauert ein Meßzyḱlus ca. 1,4s. Viel schneller as 2s scheint die PanelDue nicht zu schaffen.
var Wartezeit = 500             ; Millisekunden zusätzlich zur Dauer der Messung
var Nachrichtenanzeige = 1.4    ; Sekunden. So anpassen, daß die PanelDue keinen Schluckauf kriegt...

; Homing auf jeden Fall durchführen, um die Achsen aus dem Weg zu haben!
; Macht eh Sinn, damit die Referenzpunkte frisch sind.
G28                             ; Homing durchführen

; Nachricht
; M291 S2 P"Bitte die Befestigungsschrauben von Hotend 2 lockern! Dann mit ''OK'' fortsetzen." R"Hinweis"

; Plattform auf 120mm fahren, dann Glasplatte entfernen
G1 H2 Z180 F6000                ; Bett ca. 30mm hochfahren
M400                            ; warten, bis die Bewegung abgeschlossen ist
M291 S4 K{"Weiter","Abbruch"} T1 P"Bitte die Glasplatte vom Druckbett entfernen und die Befestigungsschrauben von Hotend 2 lockern! Dann mit ''Weiter'' den Kalibriervorgang fortsetzen." R"Z-Korrektur Hotend 2"
if input = 1
    abort

; Druckköpfe und Bett aufheizen
M140 S60                        ; Bett auf 60°C aufheizen
T0 P0
M568 P0 S220 R220               ; Hotend 1 auf 220°C aufheizen, auch im Standby
T1 P0
M568 P1 S220 R220               ; Hotend 2 auf 220°C aufheizen, auch im Standby
T-1 P0
M116                            ; warten, bis die Temperaturen von Druckkopf und Bett erreicht sind

; Druckköpfe in Putzposition bewegen
G1 H2 X{move.axes[0].min+50} F3000  ; Hotend 1 50mm von der Parkposition wegbewegen, um die Düse abwischen zu können
G1 H2 U{move.axes[3].max-50} F3000  ; Hotend 2 50mm von der Parkposition wegbewegen, um die Düse abwischen zu können
M400                                ; warten, bis die Bewegung abgeschlossen ist

; Nachricht
M291 S2 P"Z-Abgleich ist nur mit sauberen Druckdüsen möglich. Bitte Materialreste von Druckbett und Hotends entfernen! Dann mit ''OK'' fortsetzen." R"Hinweis"


; Druckköpfe zurückbewegen
G1 H2 X{move.axes[0].min} F3000     ; Hotend 1 zurück auf Endposition
G1 H2 U{move.axes[3].max} F3000     ; Hotend 2 zurück auf Endposition


; Bett hochbewegen
G1 H2 Z2 F6000                      ; Bett auf Z=2 fahren
; !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
; ACHTUNG: Bett immer erst dann ins negative fahren, wenn das Hotend an seinem Platz steht, sonst kann es sich an den Druckplattenhaltern verhaken!
; !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

; Motorströme zur Sicherheit reduzieren
M913 Z50                            ; Motorstrom auf 70% reduzieren

; Meßpunkt vorn rechts mit Hotend 1 anfahren
G1 H2 X114.5 Y-93 F15000            ; Hotend 1 zu Einstellschraube 3 (vo.re) fahren
M400                                ; warten, bis die Bewegung abgeschlossen ist
G1 H2 Z{-global.Druckplattendicke + var.Startmesshoehe} F6000   ; Bett wieder ganz hoch fahren
M400

; 1. Messung = Referenzmessung durchführen
M558 P8 C"^!io7.in" H5 F50 R0.2 T720 K0 B0          ; Meßgeschwindigkeit heruntersetzen
G31 K0 P500 X0 Y0 Z{-global.Druckplattendicke-2}    ; Z-Sensor Hotend 1: Triggerwert, Offset und Auslösehöhe


while iterations <3                ; 3x messen ohne den Wert zu speichern, damit sich das Hotend setzt
    G4 P{var.Wartezeit}            ; warten
    G30 S-1 K0
    G1 H2 Z{sensors.probes[0].lastStopHeight + var.Startmesshoehe} F3000    ; wieder anheben
    if sensors.probes[0].lastStopHeight = 0
        M291 S2 K{"Abbruch",} T1 P"Meßpunkt konnte nicht ermittelt werden. Bitte die Grenze der Z-Achse in z_max.g manuell korrigieren" R"Fehler"
        if input = 0
            abort

; Referenzwertarray füllen
while iterations < #var.Referenzwert    ; so oft wie von der Arraygröße vorgegeben messen
    G4 P{var.Wartezeit}                 ; warten
    G30 S-1 K0                          ; Z mit dem linken Hotend messen
    set var.Referenzwert[iterations] = sensors.probes[0].lastStopHeight
    G1 H2 Z{sensors.probes[0].lastStopHeight + var.Startmesshoehe} F3000                ; wieder anheben

; Mittelwert errechnen
while iterations < #var.Referenzwert
    set var.Referenzmittelwert = var.Referenzmittelwert + var.Referenzwert[iterations]
set var.Referenzmittelwert = var.Referenzmittelwert / #var.Referenzwert

; Standardabweichung errechnen
while iterations < #var.Referenzwert
    set var.Referenzstandardabw = var.Referenzstandardabw + (var.Referenzwert[iterations] - var.Referenzmittelwert) * (var.Referenzwert[iterations] - var.Referenzmittelwert)
set var.Referenzstandardabw = sqrt(var.Referenzstandardabw / (#var.Referenzwert - 1))

; Z-Score für jeden Meßwert errechnen
while iterations < #var.Referenzwert
    set var.ReferenzZScore[iterations] = (var.Referenzwert[iterations] - var.Referenzmittelwert) / var.Referenzstandardabw

; für falsch befundene Werte rauswerfen und richtigen Mittelwert errechnen
set var.Referenzmittelwert = 0
while iterations < #var.Referenzwert
    if var.ReferenzZScore[iterations] < var.ZScoregrenze            ; nur Werte nehmen, die keine Ausreißer sind 
        set var.Referenzmittelwert = var.Referenzmittelwert + var.Referenzwert[iterations]
        set var.Anzahlgueltig = var.Anzahlgueltig + 1
set var.Referenzmittelwert = var.Referenzmittelwert / var.Anzahlgueltig

M558 P8 C"^!io7.in" H2 F150 R0.2 T720 K0 B0         ; Meßgeschwindigkeit wieder normal
G31 K0 P500 X0 Y0 Z{-global.Druckplattendicke-2}    ; Z-Sensor Hotend 1: Triggerwert, Offset und Auslösehöhe



; 2. Messung mit dem rechten Hotend durchführen und den Benutzer korrigieren lassen

; Bett wieder aus dem Weg bewegen
G1 H2 Z2 F6000                      ;  Bett wieder auf Z=2 bewegen

; Meßpunkt vorn rechts mit Hotend 2 anfahren
G1 H2 X{move.axes[0].min} F4500     ; Hotend 1 zurückfahren
M400                                ; warten, bis die Bewegung abgeschlossen ist
G1 H2 U114.5 Y-93 F4500             ; Hotend 2 zu Einstellschraube 2 (vo.li) fahren
M400                                ; warten, bis die Bewegung abgeschlossen ist
G1 H2 Z{-global.Druckplattendicke + var.Startmesshoehe} F6000   ; Bett wieder ganz hoch fahren
M400                                ; warten, bis die Bewegung abgeschlossen ist

; Loop starten
while var.Messung1 = false
    set var.loopcount = 0           ; falls aus der inneren Schleife rausgehüpft wird, Loopcounter resetten
    G4 P{var.Wartezeit}             ; warten
    G30 S-1 K1                      ; Z mit dem rechten Hotend messen
    set var.Wert_Hotend2 = sensors.probes[1].lastStopHeight - var.Referenzmittelwert
    G1 H2 Z{move.axes[2].machinePosition + var.Startmesshoehe} F3000    ; wieder anheben
    if var.Wert_Hotend2 > 0.5
        M291 S1 T{var.Nachrichtenanzeige} P">|<==========-__-==========" R"Hotend-Einstellrad drehen"
    elif var.Wert_Hotend2 <= 0.5 && var.Wert_Hotend2 > 0.45
        M291 S1 T{var.Nachrichtenanzeige} P"=>|<=========-__-==========" R"Hotend-Einstellrad drehen"
    elif var.Wert_Hotend2 <= 0.45 && var.Wert_Hotend2 > 0.4
        M291 S1 T{var.Nachrichtenanzeige} P"==>|<========-__-==========" R"LHotend-Einstellrad drehen"
    elif var.Wert_Hotend2 <= 0.4 && var.Wert_Hotend2 > 0.35
        M291 S1 T{var.Nachrichtenanzeige} P"===>|<=======-__-==========" R"Hotend-Einstellrad drehen"
    elif var.Wert_Hotend2 <= 0.35 && var.Wert_Hotend2 > 0.3
        M291 S1 T{var.Nachrichtenanzeige} P"====>|<======-__-==========" R"Hotend-Einstellrad drehen"
    elif var.Wert_Hotend2 <= 0.3 && var.Wert_Hotend2 > 0.25
        M291 S1 T{var.Nachrichtenanzeige} P"=====>|<=====-__-==========" R"Hotend-Einstellrad drehen"
    elif var.Wert_Hotend2 <= 0.25 && var.Wert_Hotend2 > 0.2
        M291 S1 T{var.Nachrichtenanzeige} P"======>|<====-__-==========" R"Hotend-Einstellrad drehen"
    elif var.Wert_Hotend2 <= 0.2 && var.Wert_Hotend2 > 0.15
        M291 S1 T{var.Nachrichtenanzeige} P"=======>|<===-__-==========" R"Hotend-Einstellrad drehen"
    elif var.Wert_Hotend2 <= 0.15 && var.Wert_Hotend2 > 0.1
        M291 S1 T{var.Nachrichtenanzeige} P"========>|<==-__-==========" R"Hotend-Einstellrad drehen"
    elif var.Wert_Hotend2 <= 0.1 && var.Wert_Hotend2 > 0.05
        M291 S1 T{var.Nachrichtenanzeige} P"=========>|<=-__-==========" R"Hotend-Einstellrad drehen"
    elif var.Wert_Hotend2 <= 0.05 && var.Wert_Hotend2 > 0.03
        M291 S1 T{var.Nachrichtenanzeige} P"==========>|<-__-==========" R"Hotend-Einstellrad drehen"
            ; There is no non-blocking and time-out-able message the user can acknowledge
            ; Workaround: verify measurement several times, then display a blocking message
    elif var.Wert_Hotend2 <= 0.03 && var.Wert_Hotend2 >= -0.03
        while var.Wert_Hotend2 <= 0.03 && var.Wert_Hotend2 >= -0.03 && var.loopcount <= 6    ; okay, but verify some times...
            if iterations > 0                   ; nicht für die erste Runde, da wurde ja oben schon gemessen
                G4 P{var.Wartezeit}             ; 0,2s warten
                G30 S-1 K1                      ; Z mit dem linken Hotend messen
                set var.Wert_Hotend2 = sensors.probes[1].lastStopHeight - var.Referenzmittelwert
                G1 H2 Z{move.axes[2].machinePosition + var.Startmesshoehe} F3000    ; wieder anheben
            if var.Wert_Hotend2 <= 0.03 && var.Wert_Hotend2 > 0.01          ; just okay
                M291 S1 T{var.Nachrichtenanzeige} P"==========->|<__-==========" R"Hotend-Einstellrad drehen"
                set var.loopcount = var.loopcount + 1
            elif var.Wert_Hotend2 <= 0.01 && var.Wert_Hotend2 >= -0.01      ; perfect
                M291 S1 T{var.Nachrichtenanzeige} P"==========-_>|<_-==========" R"Hotend-Einstellrad drehen"
                set var.loopcount = var.loopcount + 1
            elif var.Wert_Hotend2 < -0.01 && var.Wert_Hotend2 >= -0.03      ; just okay
                M291 S1 T{var.Nachrichtenanzeige} P"==========-__>|<-==========" R"Hotend-Einstellrad drehen"
                set var.loopcount = var.loopcount + 1
            if var.loopcount = 6 && var.Wert_Hotend2 <= 0.03 && var.Wert_Hotend2 >= -0.03
                M300 S2000 P200                 ; B
                G4 P200                         ; e
                M300 S2500 P300                 ; e
                G4 P300                         ; p
                M291 S4 K{"Fertig","Zurück"} T1 P"Höhe des rechten Hotends justiert! Messung beenden?" R"Z-Höhe Hotend justiert"
                if input = 0
                    set var.Messung1 = true
                    set var.loopcount = 99      ; raus aus dem ganzen While-Gedöns
                if input = 1
                    set var.loopcount = 0
    elif var.Wert_Hotend2 < -0.03 && var.Wert_Hotend2 >= -0.05
        M291 S1 T{var.Nachrichtenanzeige} P"==========-__->|<==========" R"Hotend-Einstellrad drehen"
    elif var.Wert_Hotend2 < -0.05 && var.Wert_Hotend2 >= -0.1
        M291 S1 T{var.Nachrichtenanzeige} P"==========-__-=>|<=========" R"Hotend-Einstellrad drehen"
    elif var.Wert_Hotend2 < -0.1 && var.Wert_Hotend2 >= -0.15
        M291 S1 T{var.Nachrichtenanzeige} P"==========-__-==>|<========" R"Hotend-Einstellrad drehen"
    elif var.Wert_Hotend2 < -0.15 && var.Wert_Hotend2 >= -0.2
        M291 S1 T{var.Nachrichtenanzeige} P"==========-__-===>|<=======" R"Hotend-Einstellrad drehen"
    elif var.Wert_Hotend2 < -0.2 && var.Wert_Hotend2 >= -0.25
        M291 S1 T{var.Nachrichtenanzeige} P"==========-__-====>|<======" R"Hotend-Einstellrad drehen"
    elif var.Wert_Hotend2 < -0.25 && var.Wert_Hotend2 >= -0.3
        M291 S1 T{var.Nachrichtenanzeige} P"==========-__-=====>|<=====" R"Hotend-Einstellrad drehen"
    elif var.Wert_Hotend2 < -0.3 && var.Wert_Hotend2 >= -0.35
        M291 S1 T{var.Nachrichtenanzeige} P"==========-__-======>|<====" R"Hotend-Einstellrad drehen"
    elif var.Wert_Hotend2 < -0.35 && var.Wert_Hotend2 >= -0.4
        M291 S1 T{var.Nachrichtenanzeige} P"==========-__-=======>|<===" R"Hotend-Einstellrad drehen"
    elif var.Wert_Hotend2 < -0.4 && var.Wert_Hotend2 >= -0.45
        M291 S1 T{var.Nachrichtenanzeige} P"==========-__-========>|<==" R"Hotend-Einstellrad drehen"
    elif var.Wert_Hotend2 < -0.45 && var.Wert_Hotend2 >= -0.5
        M291 S1 T{var.Nachrichtenanzeige} P"==========-__-=========>|<=" R"Hotend-Einstellrad drehen"
    elif var.Wert_Hotend2 < -0.5 
        M291 S1 T{var.Nachrichtenanzeige} P"==========-__-==========>|<" R"Hotend-Einstellrad drehen"



G1 H2 Z5 F6000                      ; Bett wieder auf Z=5 bewegen
M913 Z100                           ; Motorstrom wieder auf Nennwert
G1 H2 U{move.axes[3].max} Y{move.axes[1].min} F3000     ; Druckkopf wieder zurückfahren
G1 Z120 F6000                       ; Z wieder auf 120mm
M568 P0 S0 R0                       ; Hotend 1 aus
M568 P1 S0 R0                       ; Hotend 2 aus
M140 S0                             ; Bett aus
M291 S2 P"Z-Justage des rechten Hotends abgeschlossen! Bitte Druckplatte wieder auflegen und die Hotend-Schrauben anziehen!"
